@@ -208,6 +208,51 @@ insert_nickname (SuggestionsData    *data,
     e_contact_name_free (name);
 }
 
+static guint
+str_hash_no_case (gconstpointer v)
+{
+    gchar *lower;
+    guint hash;
+
+    lower = g_ascii_strdown (v, -1);
+    hash = g_str_hash  (lower);
+    g_free (lower);
+
+    return hash;
+}
+
+static gboolean
+str_equal_no_case (gconstpointer v1,
+                   gconstpointer v2)
+{
+    return g_ascii_strcasecmp (v1, v2) == 0;
+}
+
+static GHashTable *
+get_common_ids (void)
+{
+    static gchar *a[] = {
+        "admin",
+        "info",
+        "sales",
+        "webmaster",
+        "enquiries",
+        "abuse",
+        "postmaster",
+        "service",
+        "register",
+        "hostmaster",
+    };
+    GHashTable *table;
+    guint i;
+
+    table = g_hash_table_new (str_hash_no_case, str_equal_no_case);
+
+    for (i = 0; i < G_N_ELEMENTS (a); i++)
+        g_hash_table_insert (table, a[i], GUINT_TO_POINTER (TRUE));
+
+    return table;
+}
 static void
 insert_id (SuggestionsData  *data,
            OssoABookContact *contact,
@@ -216,6 +261,7 @@ insert_id (SuggestionsData  *data,
 {
     gchar *modified_value;
     gchar *tmp;
+    static GHashTable *common_ids = NULL;
     EContactName *ename;
 
     DEBUG ("    Add token for ID %s", id);
@@ -227,18 +273,22 @@ insert_id (SuggestionsData  *data,
     tmp = strpbrk (modified_value, "@%");
     if (tmp)
         *tmp = '\0';
-    /* FIXME: maybe we should skip admin, info, jobs and webmaster? */
-    DEBUG ("    Add token for partial ID %s", modified_value);
-    match_tokens_table_add (data->partial_ids, modified_value, contact,
-            description, TRUE);
 
-    /* Try to use the local part of the ID as a name */
-    g_strdelimit (modified_value, "-_.?/+", ' ');
-    DEBUG ("    Add tokens for parsed ID %s:", modified_value);
-    ename = e_contact_name_from_string (modified_value);
-    inster_generic_name (data, contact, ename, description);
+    if (!common_ids)
+      common_ids = get_common_ids ();
+
+    if (!g_hash_table_lookup (common_ids, modified_value)) {
+        match_tokens_table_add (data->partial_ids, modified_value, contact,
+                description, TRUE);
+
+        /* Try to use the local part of the ID as a name */
+        g_strdelimit (modified_value, "-_.?/+", ' ');
+        DEBUG ("    Add tokens for parsed ID %s:", modified_value);
+        ename = e_contact_name_from_string (modified_value);
+        inster_generic_name (data, contact, ename, description);
+        e_contact_name_free (ename);
+    }
 
-    e_contact_name_free (ename);
     g_free (modified_value);
 }
 
